@@ -16,7 +16,6 @@ from base import *
 from results import *
 import solver
 import reader
-#import testing
 from parallel import *
 
 pyutilib.component.core.PluginGlobals.pop_env()
@@ -30,6 +29,6 @@ try:
     #
     for entrypoint in pkg_resources.iter_entry_points('coopr.opt'):
         plugin_class = entrypoint.load()
-except:
-    pass
+except Exception, err:
+    print "Error loading coopr.opt entry points:",str(err)
 
