@@ -1,6 +1,7 @@
 
 __all__ = ['UndefinedData', 'undefined', 'ignore', 'ScalarData', 'ListContainer', 'MapContainer', 'default_print_options', 'ScalarType']
 
+import pyutilib.math
 from pyutilib.misc import Bunch
 from pyutilib.enum import EnumValue, Enum
 import StringIO
@@ -83,6 +84,10 @@ class ScalarData(object):
         if option.ignore_time and str(self.scalar_type) == str(ScalarType.time):
             return ignore
         value = self.yaml_fix(self.get_value())
+        if value is pyutilib.math.infinity:
+            value = '.inf'
+        elif value is - pyutilib.math.infinity:
+            value = '-.inf'
         if not option.schema and self.description is None and self.units is None:
             print >>ostream, value
         else:
@@ -195,6 +200,12 @@ class ListContainer(object):
     def __setstate__(self, state):
         self.__dict__.update(state)
 
+    def __str__(self):
+        ostream = StringIO.StringIO()
+        option=default_print_options
+        self.pprint(ostream, self._option, repn=self._repn_(self._option))
+        return ostream.getvalue()
+
 
 #
 # This class manages use-defined attributes in 
